macro_rules! btree {
() => { ... };
($($val: expr),+ $(,)?) => { ... };
}Expand description
Construct a binary tree using the leetcode sequence format, excluding the square brackets.
macro_rules! btree {
() => { ... };
($($val: expr),+ $(,)?) => { ... };
}Construct a binary tree using the leetcode sequence format, excluding the square brackets.